<template>
  <section
    :class="{ ['color' + sign.shop_color]: true, ['layout' + sign.shop_style]: true }"
    class="sign">
    <div class="shop-html">
      <div class="shop-body">
        <section v-if="sign.shop_style == 1">
          <div class="contentwidthcontainer signandprintcontent">
            <div class="rainbow1"></div>
            <div id="shopname">{{ sign.name }}</div>
            <div class="rainbow2"></div>
            <div id="yatlogo">
              <img
                width="98"
                height="81"
                :src="logo"
                id="yatlogoimg">
            </div>
            <div style="display: flex;">
              <div class="contentwidthcontainer" style="width: 210px;">
                <div id="sidebar">
                  <completed-signs />
                  <div id="recent-transactions">
                    <h1>Recent Transactions</h1>
                    <recent-sales :shop="sign" />
                  </div>
                  <headlines />
                  <action-buttons
                    :has-swiper="hasSwiper"
                    :shop="sign" />
                </div>
              </div>
              <div id="rulerdiv" style="width: 7.3rem;"></div>
              <div id="maincontent" style="width: 111rem;">
                <div id="menu" v-if="sign.admin">
                  <ul id="nav" class="tab-buttons">
                    <router-link
                      tag="li"
                      :to="{name: 'sign_and_printmain'}">
                      <a
                        :class="{selected: (this.$route.name === 'sign_and_printmain')}"
                        class="tab">Main Page
                      </a>
                    </router-link>
                    <router-link
                      tag="li"
                      :to="{name: 'sign_and_print_create_main'}">
                      <a
                        id="create-signs-button"
                        :class="{selected: (this.$route.name === 'sign_and_print_create_main')}"
                        class="tab"
                        :shop="sign">Create Signs
                      </a>
                    </router-link>
                    <router-link
                      tag="li"
                      :to="{name: 'sign_and_printaccounting'}">
                      <a
                        id="income-button"
                        :class="{selected: (this.$route.name === 'sign_and_printaccounting')}"
                        class="tab">Accounting
                      </a>
                    </router-link>
                    <div class="clear"></div>
                  </ul>
                </div>
                <div class="tabs">
                  <router-view
                    class="tab selected"
                    @simple-one="simpleOne"
                    @simple-two="simpleTwo"
                    @busy-one="busyOne"
                    @busy-two="busyTwo"
                    :shop="sign"
                    :shops="shops" />

                </div>
              </div>
              <div class="clear"></div>
            </div>
          </div>
        </section>
        <section v-if="sign.shop_style == 2">
          <div class="contentwidthcontainer th2head">
            <div id="shopname">{{ sign.name }}</div>
            <div id="yatlogo">
              <img
                width="98"
                height="81"
                :src="logo"
                id="yatlogoimg">
            </div>
          </div>
          <div class="contentwidthcontainer corkback">
            <div id="menu" v-if="sign.admin">
              <ul id="nav" class="tab-buttons">
                <router-link
                  tag="li"
                  :to="{name: 'sign_and_printmain'}">
                  <a
                    :class="{selected: (this.$route.name === 'sign_and_printmain')}"
                    class="tab">Main Page
                  </a>
                </router-link>
                <router-link
                  tag="li"
                  :to="{name: 'sign_and_print_create_main'}">
                  <a
                    id="create-signs-button"
                    :class="{selected: (this.$route.name === 'sign_and_print_create_main')}"
                    class="tab"
                    :shop="sign">Create Signs
                  </a>
                </router-link>
                <router-link
                    tag="li"
                    :to="{name: 'sign_and_printaccounting'}">
                    <a
                      id="income-button"
                      :class="{selected: (this.$route.name === 'sign_and_printaccounting')}"
                      class="tab">Accounting
                    </a>
                  </router-link>
                <div class="clear"></div>
              </ul>
            </div>
            <div class="clear"></div>
            <div id="sidebar">
              <completed-signs />
              <div id="recent-transactions">
                <h1>Recent Transactions</h1>
                <recent-sales :shop="sign" />
              </div>
              <headlines />
              <action-buttons
                :has-swiper="hasSwiper"
                :shop="sign" />
            </div>
            <div id="maincontent">
              <div class="pin" id="pinleft"></div>
              <div class="pin" id="pinright"></div>
              <div class="tabs">
                <router-view
                  class="tab selected"
                  @simple-one="simpleOne"
                  @simple-two="simpleTwo"
                  @busy-one="busyOne"
                  @busy-two="busyTwo"
                  :shop="sign"
                  :shops="shops" />
              </div>
            </div>
            <div class="clear"></div>
          </div>
          <div class="clear"></div>
        </section>
      </div>
    </div>
  </section>
</template>

<script>
import ShopBaseView from '../shopBase.js';
import Headlines from '../Headlines.vue';
import ActionButtons from '../ActionButtons.vue';
import CompletedSigns from './components/CompletedSigns.vue';
import RecentSales from '../RecentSales.vue';

export default {
  extends: ShopBaseView,
  components: {
    Headlines,
    ActionButtons,
    CompletedSigns,
    RecentSales
  },
  data() {
    return {
      ref: 'newspaper_canvas',
      logo: app.network.data.shop_logo,
      sign: {},
      payments: null,
      hasSwiper: app.computerSettings.swiper,
      shops: [],
    }
  },
  methods: {
    getData() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/sign_and_print/" + app.session.data.id )
          .then( Response => {
            this.sign = Response;
            app.Message( "Successfully loaded the Sign & Print Shop!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) )
        })
    },
    getShops() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/economies/getAllWithAccountIds/" + app.session.data.id)
          .then( Response => {
            Response.forEach(shop => {
              this.shops.push({name: shop.pretty_name, account: shop.accountId});
            });
          })
          .catch( x => app.Message( x.error, "error" ) )
        })
    },
    simpleOne() {
      this.sign.shop_style = 1;
      this.sign.shop_color = 1;
    },
    simpleTwo() {
      this.sign.shop_style = 1;
      this.sign.shop_color = 2;
    },
    busyOne() {
      this.sign.shop_style = 2;
      this.sign.shop_color = 1;
    },
    busyTwo() {
      this.sign.shop_style = 2;
      this.sign.shop_color = 2;
    }
  },
  created: function () {
    this.getData();
    this.getShops();
  },
  beforeMount: function () {
    this.$router.push({name: 'sign_and_printmain'});
  }
}
</script>

<style lang="less">
  @import '../../shared.less';
</style>

<style lang="less">

@font-face {
    font-family: 'chunkfiveroman';
    src: url('/fonts/chunkfive/chunkfive-webfont.eot');
    src: url('/fonts/chunkfive/chunkfive-webfont.eot?#iefix') format('embedded-opentype'),
        url('/fonts/chunkfive/chunkfive-webfont.woff') format('woff'),
        url('/fonts/chunkfive/chunkfive-webfont.ttf') format('truetype'),
        url('/fonts/chunkfive/chunkfive-webfont.svg#chunkfiveroman') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'mouse_memoirsregular';
    src: url('/fonts/mousememoirs/mousememoirs-regular-webfont.eot');
    src: url('/fonts/mousememoirs/mousememoirs-regular-webfont.eot?#iefix') format('embedded-opentype'),
        url('/fonts/mousememoirs/mousememoirs-regular-webfont.woff') format('woff'),
        url('/fonts/mousememoirs/mousememoirs-regular-webfont.ttf') format('truetype'),
        url('/fonts/mousememoirs/mousememoirs-regular-webfont.svg#mouse_memoirsregular') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'open_sansregular';
    src: url('/fonts/opensans/opensans-regular-webfont.eot');
    src: url('/fonts/opensans/opensans-regular-webfont.eot?#iefix') format('embedded-opentype'),
        url('/fonts/opensans/opensans-regular-webfont.woff') format('woff'),
        url('/fonts/opensans/opensans-regular-webfont.ttf') format('truetype'),
        url('/fonts/opensans/opensans-regular-webfont.svg#open_sansregular') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'pacificoregular';
    src: url('/fonts/pacifico/pacifico-webfont.eot');
    src: url('/fonts/pacifico/pacifico-webfont.eot?#iefix') format('embedded-opentype'),
        url('/fonts/pacifico/pacifico-webfont.woff') format('woff'),
        url('/fonts/pacifico/pacifico-webfont.ttf') format('truetype'),
        url('/fonts/pacifico/pacifico-webfont.svg#pacificoregular') format('svg');
    font-weight: normal;
    font-style: normal;

}

@font-face {
    font-family: 'pointy_demoregular';
    src: url('/fonts/pointy/pointy_demo-webfont.eot');
    src: url('/fonts/pointy/pointy_demo-webfont.eot?#iefix') format('embedded-opentype'),
        url('/fonts/pointy/pointy_demo-webfont.woff') format('woff'),
        url('/fonts/pointy/pointy_demo-webfont.ttf') format('truetype'),
        url('/fonts/pointy/pointy_demo-webfont.svg#pointy_demoregular') format('svg');
    font-weight: normal;
    font-style: normal;

}

.mouse {
  font-family: 'Mouse Memoirs';
}
.chunk {
  font-family: 'chunkfiveroman';
}
.opensans {
  font-family:'open_sansregular';
}
.pacifico {
  font-family:'pacificoregular';
}
.pointy {
  font-family:'pointy_demoregular';
}
.bungee {
  font-family:'Bungee Shade';
}
.upper-canvas {
  border:2px solid #C5C5C5;
}
#fontSelect {
  border: none;
  background: #fff;
  color: #0f70b3;
  font-family: "Mouse Memoirs";
  font-size: 22px;
  padding: 7px 12px;
  border-radius: 8px;
  margin: 0px 10px 0 0;
}
.fontSelectLabel {
  display:inline !important;
  vertical-align:middle;
  margin-right:5px;
}
.canvasRibbon {
  padding: 2rem !important;
}
.canvasRibbon a.button {
  vertical-align:middle;
}
.fontContainer {
  display:inline;
}
.sign.color1.layout1 {
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgimage2: url(/images/shop/townhall/townhall2bigbg.jpg);
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;

  @maincontentcolor: #131736;

  .shopbuttonstyles() {
      background-color: #ffa400;
      border-color: #ffdb99;
      color: #fff;
  }
  .bodyback() {
      background-image: @bgimage;
  background-repeat:no-repeat;
  background-position:center 0;
  }
  .fullback() {
      background-image: none;
  }
  /* Sign and Print color 1*/
  @shoptitlecolor: #ff4d4d;
  @logoborder: 0.5rem solid #00ff2a;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @bgimage: url(/images/shop/signandprint/signandprintbigbg.png);
  @rainbow1: url(/images/shop/signandprint/rainbow1.png);
  @rainbow2: url(/images/shop/signandprint/rainbow2.png);
  @activetabcolor: #ff4d4d;
  @activetabshadow: #ca3c3c;
  @navbgcolor: #b2f7be;
  @tabfontcolor: #419a50;
  @maincontenth1 :#005c0f;
  @maincontentp :#008e18;
  @buttonbackground :#3dcc55;
  @buttonborder :#89e097;
  @buttonborderhover :#ff9999;
  @controlbg: #E5DAFF;
  @controlh2bg: #7460A0;
  @controlborder: transparent;

  @import './signAndPrintLayout1.less';
}
</style>

<style lang="less">
.sign.color2.layout1 {
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgimage2: url(/images/shop/townhall/townhall2bigbg.jpg);
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;

  @maincontentcolor: #131736;

  .shopbuttonstyles() {
      background-color: #ffa400;
      border-color: #ffdb99;
      color: #fff;
  }
  .bodyback() {
      background-image: @bgimage;
  background-repeat:no-repeat;
  background-position:center 0;
  }
  .fullback() {
      background-image: none;
  }
  /* Sign and Print color 2 */
  @shoptitlecolor: #337399;
  @logoborder: 0.5rem solid #aaaaaa;
  @shopdesccolor:#b33636;
  @homemsgcolor:#7f0000;
  @bgimage: url(/images/shop/signandprint/signandprintbigbg2.png);
  @rainbow1: url(/images/shop/signandprint/rainbow1bw.png);
  @rainbow2: url(/images/shop/signandprint/rainbow2bw.png);
  @activetabcolor: #337399;
  @activetabshadow: #224d66;
  @navbgcolor: #b3ddf5;
  @tabfontcolor: #337399;
  @hometxtcolor: #337399;
  @maincontenth1 :#135379;
  @maincontentp :#337399;
  @buttonbackground :#73b3d9;
  @buttonborder :#b3ddf5;
  @buttonborderhover :#63a3c9;
  @controlbg: lighten(#918361, 44%);
  @controlh2bg: #918361;
  @controlborder: lighten(#918361, 20%);

  @import './signAndPrintLayout1.less';
}
</style>

<style lang="less">
.sign.color1.layout2 {
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgimage2: url(/images/shop/townhall/townhall2bigbg.jpg);
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;


  @maincontentcolor: #131736;

  .shopbuttonstyles() {
      background-color: #ffa400;
      border-color: #ffdb99;
      color: #fff;
  }
  .bodyback() {
      background-color:@bgcolor;
  }
  .fullback() {
      background-image: none;
  }
  /* Sign and Print color 1*/
  @bgcolor: #47a0d4;
  @shoptitlecolor: #fff;
  @logoborder: 0.5rem solid #2a6080;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @bgimage: url(/images/shop/signandprint/signandprintbigbg.png);
  @rainbow1: url(/images/shop/signandprint/rainbow1.png);
  @rainbow2: url(/images/shop/signandprint/rainbow2.png);
  @activetabcolor: #ff4d4d;
  @navbgcolor: #b2f7be;
  @tabfontcolor: #419a50;
  @hometxtcolor:#008dd0;
  @textshadow2: #327297;
  @navpencil:url('/images/shop/signandprint/navpencilblue.png');
  @navpencilactive:url('/images/shop/signandprint/navpencilred.png');
  @buttonbg: #33c2ff;
  @buttonborder: #b2e8ff;
  @buttonhover: #e90101;
  @buttonborderhover: #ff8282;
  @controlbg: #E5DAFF;
  @controlh2bg: #7460A0;

  @import './signAndPrintLayout2.less';
}
</style>

<style lang="less">
.sign.color2.layout2 {
  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @bgimage2: url(/images/shop/townhall/townhall2bigbg.jpg);
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;


  @maincontentcolor: #131736;

  .shopbuttonstyles() {
      background-color: #ffa400;
      border-color: #ffdb99;
      color: #fff;
  }
  .bodyback() {
      background-color:@bgcolor;
  }
  .fullback() {
      background-image: none;
  }

    /* Sign and Print color 2*/
  @bgcolor: #432300;
  @shoptitlecolor: #fff;
  @logoborder: 0.5rem solid #e37700;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @bgimage: url(/images/shop/signandprint/signandprintbigbg.png);
  @rainbow1: url(/images/shop/signandprint/rainbow1.png);
  @rainbow2: url(/images/shop/signandprint/rainbow2.png);
  @activetabcolor: #ff4d4d;
  @navbgcolor: #b2f7be;
  @tabfontcolor: #419a50;
  @hometxtcolor:#432300;
  @textshadow2: #2b1600;
  @navpencil:url('/images/shop/signandprint/navpencilyellow.png');
  @navpencilactive:url('/images/shop/signandprint/navpencilbrown.png');
  @buttonbg: #ff9633;
  @buttonborder: #ffd7b2;
  @buttonhover: #5c2c00;
  @buttonborderhover: #a87d54;
  @controlbg: lighten(#A87D54, 40%);
  @controlh2bg: #603100;
  @import './signAndPrintLayout2.less';
}
</style>
